|
Our proposed method avoids the computation of dominance relation for each object which consequently reduce the time require to update approximations. Extensive experiments are conducted on UCI datasets. As results already discussed, our proposed algorithm proves efficient with an average reduction of 98% without compromising accuracy. The computational complexity also reduced to quadratic as compared to cubic complexity of the traditional method. In future, we want to explore the variation in the value set of attributes (conditional and decision attribute) along with object set variations.
|